# coding: utf-8

import pytest
import textwrap


def test_style(css):
    assert css._parent is None
    assert css.QWidget == css.QWidget.item._parent


def test_style_recursive(css):
    css["test"].setValue(3)
    assert css["test"].value == 3
    css.QWidget.color.setValue("green")
    assert css.QWidget.color.value == "green"
    assert css["QWidget"]["color"].value == "green"
    css["QWidget"]["color"].setValue("blue")
    assert css["QWidget"]["color"].value == "blue"
    assert css.QWidget.color.value == "blue"


def test_delete_style(css):
    css.QWidget.color.setValue("blue")
    assert "color" in css.QWidget.keys()
    del css.QWidget.color
    assert "color" not in css.QWidget.keys()
    css.QWidget["color"].setValue("blue")
    assert "color" in css.QWidget.keys()
    del css.QWidget["color"]
    assert "color" not in css.QWidget.keys()


def test_subcontrol(css):
    import qstylizer.style
    assert type(css.QWidget.item) == qstylizer.style.SubControlRule


def test_pseudo_state(css):
    import qstylizer.style
    assert type(css.QWidget.item.selected) == qstylizer.style.PseudoStateRule


def test_selector(css):
    assert css.QCheckBox.indicator.selector == "QCheckBox::indicator"
    assert css.QCheckBox.indicator.unchecked.selector == "QCheckBox::indicator:unchecked"
    assert css.QCheckBox.indicator.unchecked.hover.selector == "QCheckBox::indicator:unchecked:hover"
    assert css["Object"]["subcontrol"]["pseudostate"].selector == "Object::subcontrol:pseudostate"
    assert css["Object::subcontrol:pseudostate"].selector == "Object::subcontrol:pseudostate"
    assert css.QLineEdit['[echoMode="2"]'].selector == "QLineEdit[echoMode=\"2\"]"
    assert css["Object"]["::subcontrol"][":pseudostate"].selector == "Object::subcontrol:pseudostate"
    assert css["QWidget#objectName"].selector == "QWidget#objectName"


def test_style_list(css):
    css["QCheckBox, QLineEdit, QFrame"].border = "none"
    css["QWidget,#objectName"].border = "none"
    css["*,\nQCheckBox::subcontrol:pseudostate"].margin = "none"
    assert "QCheckBox" in css.keys()
    assert "QLineEdit" in css.keys()
    assert "QWidget" in css.keys()
    assert "#objectName" in css.keys()
    assert "border" in css.QWidget.keys()
    assert "border" in css.QLineEdit.keys()
    assert "margin" in css["QCheckBox::subcontrol:pseudostate"].keys()
    assert css.toString() == textwrap.dedent(
        """
        * {
            margin: none;
        }
        QCheckBox {
            border: none;
        }
        QLineEdit {
            border: none;
        }
        QFrame {
            border: none;
        }
        QWidget {
            border: none;
        }
        #objectName {
            border: none;
        }
        QCheckBox::subcontrol:pseudostate {
            margin: none;
        }
        """
    )[1:]


def test_style_style(css):
    css.QCheckBox.indicator.unchecked.hover.border.setValue("none")
    css.QCheckBox.indicator.unchecked.hover.color.setValue("green")
    assert css.QCheckBox.indicator.unchecked.hover.toString() == \
           "QCheckBox::indicator:unchecked:hover {\n    border: none;\n    color: green;\n}\n"


def test_to_string_recursive(css):
    css.border.setValue("none")
    css.QFrame.border.setValue("1px solid green")
    css.QFrame.color.setValue("green")
    css.QCheckBox.border.setValue("1px solid green")
    css.QCheckBox.color.setValue("green")
    css.QCheckBox.indicator.backgroundColor.setValue("red")
    css.QCheckBox.indicator.unchecked.border.setValue("none")
    css.QCheckBox.indicator.unchecked.backgroundColor.setValue("rgb(0,20,0)")
    css.QCheckBox.indicator.unchecked.hover.backgroundColor.setValue("purple")
    css.QLineEdit['[echoMode="2"]']["lineedit-password-character"].setValue(9679)
    css["QCheckBox::indicator:unchecked"].margin.setValue(0)
    assert css.toString() == textwrap.dedent(
        """
        * {
            border: none;
        }
        QFrame {
            border: 1px solid green;
            color: green;
        }
        QCheckBox {
            border: 1px solid green;
            color: green;
        }
        QCheckBox::indicator {
            background-color: red;
        }
        QCheckBox::indicator:unchecked {
            border: none;
            background-color: rgb(0,20,0);
            margin: 0;
        }
        QCheckBox::indicator:unchecked:hover {
            background-color: purple;
        }
        QLineEdit[echoMode="2"] {
            lineedit-password-character: 9679;
        }
        """
    )[1:]


def test_empty_style(css):
    css.QCheckBox.indicator.border.setValue("none")
    assert css.QCheckBox.toString() == ""


def test_subcontrol_options():
    import qstylizer.descriptor.subcontrol
    assert 'add-line' in qstylizer.descriptor.subcontrol.SubControlParent.get_attr_options()


def test_pseudostate_options():
    import qstylizer.descriptor.pseudostate
    assert 'minimized' in qstylizer.descriptor.pseudostate.PseudoStateParent.get_attr_options()


def test_prop_semicolon(css):
    css.QComboBox.color.setValue("red;")
    assert css.QComboBox.color.value == "red"


# def test_deepcopy(css):
#     import copy
#     css.QCheckBox.indicator.hover.border.setValue("none"
#     css.QCheckBox.indicator.backgroundColor.setValue("red"
#     indicator.setValue(copy.deepcopy(css.QCheckBox.indicator)
#     indicator.color.setValue("yellow"
#     indicator.hover.border.setValue("1px solid green"
#     assert indicator is not css.QCheckBox.indicator
#     assert "color" in indicator.keys()
#     assert "color" not in css.QCheckBox.indicator.keys()
#     assert css.QCheckBox.indicator.hover.border == "none"
#     assert indicator.hover.border == "1px solid green"
#
#
# def test_assign_subcontrol(css):
#     import qstylizer.style
#     subcontrol.setValue(qstylizer.style.SubControlRule("indicator")
#     subcontrol.backgroundColor.setValue("red"
#     subcontrol.unchecked.border.setValue("none"
#     subcontrol.unchecked.backgroundColor.setValue("rgb(0,20,0)"
#     subcontrol.unchecked.hover.backgroundColor.setValue("purple"
#
#     css.QComboBox.indicator.setValue(subcontrol
#     css.QCheckBox.indicator.setValue(subcontrol
#
#     assert css.QCheckBox.indicator is not css.QComboBox.indicator
#     assert css.QCheckBox.indicator.selector == "QCheckBox::indicator"
#     assert css.QComboBox.indicator.selector == "QComboBox::indicator"


def test_child_class_style(css):
    css.QWidget.color.setValue("red")
    css["QWidget QFrame"].backgroundColor.setValue("green")
    css.QFrame.color.setValue("black")
    assert css.toString() == textwrap.dedent(
        """
        QWidget {
            color: red;
        }
        QWidget QFrame {
            background-color: green;
        }
        QFrame {
            color: black;
        }
        """
    )[1:]


def test_unscoped_style(css):
    css.backgroundColor.setValue("red")
    css.border.setValue("none")
    assert css.toString() == textwrap.dedent(
        """
        background-color: red;
        border: none;
        """
    )[1:]


def test_global_style(css):
    css.backgroundColor.setValue("red")
    css.border.setValue("none")
    css.QWidget.indicator.border.setValue("1px solid green")
    assert css.toString() == textwrap.dedent(
        """
        * {
            background-color: red;
            border: none;
        }
        QWidget::indicator {
            border: 1px solid green;
        }
        """
    )[1:]


def test_not_operator(css):
    import qstylizer.style
    css.QWidget.indicator["!selected"].color.setValue("green")
    assert type(css.QWidget.indicator["!selected"]) == qstylizer.style.PseudoStateRule
    assert css.toString() == textwrap.dedent(
        """
        QWidget::indicator:!selected {
            color: green;
        }
        """
    )[1:]


def test_pseudostate_prop_same_name(css):
    css.QWidget.top.setValue(0)
    css.QWidget.right.setValue(0)
    css.QWidget.bottom.setValue(0)
    css.QWidget.left.setValue(0)
    css.QTabBar.tab.top.color.setValue("red")
    assert css.toString() == textwrap.dedent(
        """
        QWidget {
            top: 0;
            right: 0;
            bottom: 0;
            left: 0;
        }
        QTabBar::tab:top {
            color: red;
        }
        """
    )[1:]


def test_pseudoprop_set(css):
    css.QWidget.tab.top.setValue("0")
    css.QWidget.tab.top.color.setValue("green")
    assert css.toString() == textwrap.dedent(
        """
        QWidget::tab {
            top: 0;
        }
        QWidget::tab:top {
            color: green;
        }
        """
    )[1:]


def test_add_child_rule(css):
    css.QCheckBox.indicator.backgroundColor.setValue("red")
    assert len(css._child_rules) == 3
    assert css.QCheckBox in css._child_rules.values()
    assert css.QCheckBox.indicator in css._child_rules.values()


def test_set_values(css):
    css.QToolButton.setValues(
        border="1px transparent lightblue",
        borderRadius="3px",
        margin="1px",
        padding="3px",
    )
    assert css.QToolButton.border.value == "1px transparent lightblue"


def test_global_object_prop(css):
    css["*"].color.setValue("green")
    css["*[test=\"2\"]"].color.setValue("red")
    assert css.toString() == textwrap.dedent(
        """
        * {
            color: green;
        }
        *[test="2"] {
            color: red;
        }
        """
    )[1:]


def test_global_scope(css):
    css["*"].color.setValue("red")
    css.backgroundColor.setValue("green")
    assert css.toString() == textwrap.dedent(
        """
        * {
            color: red;
            background-color: green;
        }
        """
    )[1:]


def test_update_overwrite():
    import qstylizer.parser

    style1 = """
    QWidget {
        background-color: blue;
    }
    """
    style2 = """
    QWidget {
        background-color: red;
    }
    """
    qss1 = qstylizer.parser.parse(style1)
    qss2 = qstylizer.parser.parse(style2)

    qss1.update(qss2)

    assert qss1.toString() == qss2.toString()


def test_update_overwrite_and_append():
    import qstylizer.parser

    style1 = """
    QWidget {
        background-color: blue;
    }
    QMenuBar {
        color: yellow;
    }
    """
    style2 = """
    QWidget {
        background-color: red;
    }
    QTabBar {
        color: green;
    }
    """
    qss1 = qstylizer.parser.parse(style1)
    qss2 = qstylizer.parser.parse(style2)

    qss1.update(qss2)

    assert qss1.toString() == textwrap.dedent(
        """
        QWidget {
            background-color: red;
        }
        QMenuBar {
            color: yellow;
        }
        QTabBar {
            color: green;
        }
        """
    )[1:]


def test_update_nested():
    import qstylizer.parser

    style1 = """
    QWidget {
        color: yellow;
    }
    QWidget:item {
        color: white;
    }
    """
    style2 = """
    QWidget {
        background-color: red;
    }
    QWidget:item:selected {
        background-color: blue;
    }
    """

    qss1 = qstylizer.parser.parse(style1)
    qss2 = qstylizer.parser.parse(style2)

    qss1.update(qss2)

    assert qss1.toString() == textwrap.dedent(
        """
        QWidget {
            color: yellow;
            background-color: red;
        }
        QWidget:item {
            color: white;
        }
        QWidget:item:selected {
            background-color: blue;
        }
        """
    )[1:]

    assert qss1.QWidget.color.value == "yellow"





import pytest

import qstylizer.style


@pytest.mark.parametrize(
    "selector, expected",
    [
        (
            "QComboBox",
            ["QComboBox"]
        ),
        (
            "QComboBox:pseudostate",
            ["QComboBox", ":pseudostate"]
        ),
        (
            "QComboBox::indicator:pseudostate",
            ["QComboBox", "::indicator", ":pseudostate"]
        ),
        (
            "QWidget[echoMode=2]",
            ["QWidget", "[echoMode=2]"]
        ),
        (
            'QWidget[custom_prop="1"]',
            ["QWidget", '[custom_prop="1"]']
        ),
        (
            "QWidget#objectName",
            ["QWidget", "#objectName"]
        ),
        (
            "QWidget QFrame",
            ["QWidget", " QFrame"]
        ),
        (
            "#objectName",
            ["#objectName"]
        ),
        (
            "::pseudostate",
            ["::pseudostate"]
        ),
        (
            "QTreeView::branch:!has-children:adjoins-item",
            ["QTreeView", "::branch", ":!has_children", ":adjoins_item"]
        ),
        (
            '*[custom_prop="custom_value:1"]',
            ["*", '[custom_prop="custom_value:1"]']
        )
    ],
    ids=[
        "with-single-name",
        "with-pseudostate",
        "with-indicator-and-pseudostate",
        "with-object-property",
        "with-custom-object-property",
        "with-class-and-object",
        "with-child-class",
        "with-object",
        "with-only-pseudostate",
        "with-not-operator-and-dashes",
        "with-global-custom-prop"
    ]
)
def test_split_selector(css, selector, expected):
    assert css.split_selector(selector) == expected


@pytest.mark.parametrize(
    "key, expected",
    [
        ("background-color", "background-color"),
        (":checked", "checked"),
        ("background_color", "background-color"),
        (12345, "12345"),
        ("QWidget", "QWidget"),
        ("Custom", "Custom"),
        ("CustomTabBar", "CustomTabBar"),
        ("qproperty-drawBase", "qproperty-drawBase"),
    ],
    ids=[
        "with-normal-key",
        "with-semicolon",
        "with-underscore",
        "with-nonstring",
        "with-qclassname",
        "with-capital",
        "with-camelize",
        "with-qproperty",
    ]
)
def test_sanitize_key(css, key, expected):
    assert css._sanitize_key(key) == expected


@pytest.mark.parametrize(
    "value, expected",
    [
        ("1px solid #000000", "1px solid #000000"),
        ("1px solid #000000;", "1px solid #000000"),
        (100, 100),
        (u"green;", u"green"),
    ],
    ids=[
        "with-normal-value",
        "with-semicolon",
        "with-nonstring",
        "with-unicode",
    ]
)
def test_sanitize_value(css, value, expected):
    assert css._sanitize_value(value) == expected


@pytest.mark.parametrize(
    "name, "
    "found_value, "
    "expected, "
    "rule_list_call_count, "
    "rules_call_count",
    [
        (
            "QComboBox, QCheckBox",
            None,
            "StyleRuleList",
            1,
            0
        ),
        (
            "QComboBox",
            "Value",
            "Value",
            0,
            0
        ),
        (
            "QComboBox",
            None,
            "Value",
            0,
            1
        ),
    ],
    ids=[
        "with-rule-list",
        "with-existing-class",
        "with-new-class",
    ]
)
def test_find_or_create_child_rule(
    mocker, css, style_class, name, found_value, expected,
    rule_list_call_count, rules_call_count
):
    mocked_find_child_rule = mocker.patch.object(
        style_class, "find_child_rule", return_value=found_value
    )
    mocked_create_child_rule_list = mocker.patch.object(
        style_class, "create_child_rule_list", return_value="StyleRuleList"
    )
    mocked_create_child_rules = mocker.patch.object(
        style_class, "create_child_rules", return_value=expected
    )
    assert css.find_or_create_child_rule(name) == expected
    mocked_find_child_rule.assert_called_once_with(name)
    assert mocked_create_child_rule_list.call_count == rule_list_call_count
    assert mocked_create_child_rules.call_count == rules_call_count


def test_find_child_rule(mocker, style_class, css):
    key = "KEY"
    value = "VALUE"
    mocked_sanitize_key = mocker.patch.object(
        style_class, "_sanitize_key", return_value=key
    )
    mocked_get = mocker.patch.object(
        style_class, "get", return_value=value
    )
    assert css.find_child_rule(key) == value
    mocked_sanitize_key.assert_called_once_with(key)
    mocked_get.assert_called_once_with(key)


def test_create_child_rule_list(mocker, style_class, css):
    import qstylizer.style
    style_list = "StyleListInstance"
    name = "test"
    mocker.patch.object(
        qstylizer.style, "StyleRuleList", return_value=style_list
    )
    mocked_set_child_rule = mocker.patch.object(style_class, "set_child_rule")
    assert css.create_child_rule_list(name) == style_list
    mocked_set_child_rule.assert_called_once_with(name, style_list)


@pytest.mark.parametrize(
    "selector, "
    "curr_name, "
    "find_or_create_child_rule_call_count, ",
    [
        (
            "QComboBox",
            "QComboBox",
            0,
        ),
        (
            "QComboBox::indicator",
            "QComboBox",
            1,
        ),
    ],
    ids=[
        "with-single-style",
        "with-multiple-style",
    ]
)
def test_create_child_rules(
    mocker, style_class, css, selector, curr_name,
    find_or_create_child_rule_call_count
):
    mocked_style = mocker.MagicMock()
    mocked_split_selector = mocker.patch.object(
        style_class, "split_selector", return_value=[curr_name]
    )
    mocked_find_child_rule = mocker.patch.object(
        style_class, "find_child_rule", return_value=mocked_style
    )
    mocker.patch.object(
        style_class, "create_child_rule", return_value=mocked_style
    )
    mocker.patch.object(
        style_class, "find_or_create_child_rule", return_value=mocked_style
    )
    css.create_child_rules(selector)
    mocked_split_selector.assert_called_once_with(selector)
    mocked_find_child_rule.assert_called_once_with(curr_name)
    assert (
        mocked_style.find_or_create_child_rule.call_count ==
        find_or_create_child_rule_call_count
    )


def test_create_child_rule(mocker, style_class, css):
    import qstylizer.style
    name = "::indicator"
    style = mocker.MagicMock()
    class_ = mocker.MagicMock(return_value=style)
    mocked_subclass_function = mocker.patch.object(
        qstylizer.style, "rule_class", return_value=class_
    )
    mocked_add_value = mocker.patch.object(
        style_class, "set_child_rule"
    )
    css.create_child_rule(name)
    mocked_add_value.assert_called_with(name, style)
    mocked_subclass_function.assert_called_once_with(name)
    class_.assert_called_with(name=name, parent=css)


def test_set_child_rule(css):
    rule = qstylizer.style.ClassRule("QUnknown")
    css.set_child_rule("QUnknown", rule)
    assert rule in css.values()
    css.clear()
    css.set_child_rule("Test", 20)
    assert isinstance(list(css.values())[0], qstylizer.style.PropRule)
    assert list(css.values())[0].value == 20


def test_add_child_rule(css):
    rule = qstylizer.style.ClassRule("QUnknown")
    css._add_child_rule(rule)
    assert rule in css._child_rules.values()


def test_selector():
    rule = qstylizer.style.ClassRule("QCheckBox")
    child_rule = qstylizer.style.SubControlRule("indicator")
    child_rule._parent = rule
    assert child_rule.selector == "QCheckBox::indicator"
    assert rule.selector == "QCheckBox"


def test_name():
    rule = qstylizer.style.SubControlRule("indicator")
    rule._name = "::indicator"
    assert rule.name == "indicator"


def test_scope_operator(css):
    rule = css["aaaaa"]
    child_rule = css["aaaaa"]["bbbbb"]
    child_child_rule = css["aaaaa"]["bbbbb"]["ccccc"]
    assert rule.scope_operator == ""
    assert child_rule.scope_operator == "::"
    assert child_child_rule.scope_operator == ":"


def test_is_leaf(css):
    assert css["aaaaa"].is_leaf()
    assert css["bbbbb"]["ccccc"].is_leaf()
    assert not css["bbbbb"].is_leaf()


def test_is_top_level(css):
    assert css["aaaaa"].is_top_level()
    assert not css["bbbbb"]["ccccc"].is_top_level()
    assert css["bbbbb"].is_top_level()


@pytest.mark.parametrize(
    "name, expected",
    [
        ("indicator", "SubControlRule"),
        ("has-children", "PseudoStateRule"),
        ("::subcontrol", "SubControlRule"),
        (":pseudostate", "PseudoStateRule"),
        ("#objectName", "ObjectRule"),
        ("[echoMode=2]", "ObjectPropRule"),
        (" QFrame", "ChildClassRule"),
        ("QObject", "ClassRule")
    ],
    ids=[
        "with-known-subcontrol",
        "with-known-pseudostate",
        "with-subcontrol-scope-op",
        "with-pseudostate-scope-op",
        "with-object",
        "with-object-property",
        "with-child-class",
        "with-known-class",
    ]
)
def test_style_child_rule_class(mocker, style_class, css, name, expected):
    import qstylizer.style
    assert qstylizer.style.rule_class(name).__name__ == expected




# coding: utf-8
#
# qstylizer documentation build configuration file, created by
# sphinx-quickstart on Sat Nov  4 21:16:20 2017.
#
# This file is execfile()d with the current directory set to its
# containing dir.
#
# Note that not all possible configuration values are present in this
# autogenerated file.
#
# All configuration values have a default; values that are commented out
# serve to show the default.

# If extensions (or modules to document with autodoc) are in another directory,
# add these directories to sys.path here. If the directory is relative to the
# documentation root, use os.path.abspath to make it absolute, like shown here.
#
import os
import sys
sys.path.append(
    os.path.abspath(os.path.join(os.path.dirname(__file__), ".."))
)



# -- General configuration ------------------------------------------------

# If your documentation needs a minimal Sphinx version, state it here.
#
# needs_sphinx = "1.0"

# Add any Sphinx extension module names here, as strings. They can be
# extensions coming with Sphinx (named "sphinx.ext.*") or your custom
# ones.
extensions = [
    "sphinx.ext.autodoc",
    "sphinx.ext.viewcode",
    "sphinxcontrib.autoprogram"
]

# Add any paths that contain templates here, relative to this directory.
templates_path = ["_templates"]

# The suffix(es) of source filenames.
# You can specify multiple suffix as a list of string:
#
# source_suffix = [".rst", ".md"]
source_suffix = ".rst"

# The master toctree document.
master_doc = "index"

# General information about the project.
project = u"qstylizer"
copyright = u"2017, Brett Lambright"
author = u"Brett Lambright"

# The version info for the project you"re documenting, acts as replacement for
# |version| and |release|, also used in various other places throughout the
# built documents.
#
# The short X.Y version.
# version = u"0.1.0"
# The full version, including alpha/beta/rc tags.
# release = u"0.1.0"

# The language for content autogenerated by Sphinx. Refer to documentation
# for a list of supported languages.
#
# This is also used if you do content translation via gettext catalogs.
# Usually you set "language" from the command line for these cases.
language = None

# List of patterns, relative to source directory, that match files and
# directories to ignore when looking for source files.
# This patterns also effect to html_static_path and html_extra_path
exclude_patterns = ["_build", "Thumbs.db", ".DS_Store"]

# The name of the Pygments (syntax highlighting) style to use.
pygments_style = "sphinx"

# If true, `todo` and `todoList` produce output, else they produce nothing.
todo_include_todos = False


# -- Options for HTML output ----------------------------------------------

# The theme to use for HTML and HTML Help pages.  See the documentation for
# a list of builtin themes.
#
html_theme = "sphinx_rtd_theme"

# Theme options are theme-specific and customize the look and feel of a theme
# further.  For a list of options available for each theme, see the
# documentation.
#
# html_theme_options = {}

# Add any paths that contain custom static files (such as style sheets) here,
# relative to this directory. They are copied after the builtin static files,
# so a file named "default.css" will overwrite the builtin "default.css".
html_static_path = ["_static"]

# Custom sidebar templates, must be a dictionary that maps document names
# to template names.
#
# This is required for the alabaster theme
# refs: http://alabaster.readthedocs.io/en/latest/installation.html#sidebars


# -- Options for HTMLHelp output ------------------------------------------

# Output file base name for HTML help builder.
htmlhelp_basename = "qstylizerdoc"


# -- Options for LaTeX output ---------------------------------------------

latex_elements = {
    # The paper size ("letterpaper" or "a4paper").
    #
    # "papersize": "letterpaper",

    # The font size ("10pt", "11pt" or "12pt").
    #
    # "pointsize": "10pt",

    # Additional stuff for the LaTeX preamble.
    #
    # "preamble": "",

    # Latex figure (float) alignment
    #
    # "figure_align": "htbp",
}

# Grouping the document tree into LaTeX files. List of tuples
# (source start file, target name, title,
#  author, documentclass [howto, manual, or own class]).
latex_documents = [
    (master_doc, "qstylizer.tex", u"qstylizer Documentation",
     u"Brett Lambright", "manual"),
]


# -- Options for manual page output ---------------------------------------

# One entry per manual page. List of tuples
# (source start file, name, description, authors, manual section).
man_pages = [
    (master_doc, "qstylizer", u"qstylizer Documentation",
     [author], 1)
]


# -- Options for Texinfo output -------------------------------------------

# Grouping the document tree into Texinfo files. List of tuples
# (source start file, target name, title, author,
#  dir menu entry, description, category)
texinfo_documents = [
    (master_doc, "qstylizer", u"qstylizer Documentation",
     author, "qstylizer", "One line description of project.",
     "Miscellaneous"),
]


# -- Autodoc ------------------------------------------------------------------

# autodoc_default_flags = ["members", "undoc-members", "inherited-members"]
autodoc_member_order = "bysource"


def autodoc_skip(app, what, name, obj, skip, options):
    """Don"t skip __init__ method for autodoc."""
    if name == "__init__":
        return False

    return skip


# -- Setup --------------------------------------------------------------------

def setup(app):
    app.connect("autodoc-skip-member", autodoc_skip)








# coding: utf-8

import pytest


@pytest.fixture
def css():
    import qstylizer.style
    return qstylizer.style.StyleSheet()


@pytest.fixture
def style_class():
    import qstylizer.style
    return qstylizer.style.StyleRule
